==> nextcloud-app-contacts-2.1.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/es.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contactos",
    "Download" : "Descargar",
    "Copy link" : "Copiar enlace",
    "Click to copy the link to your clipboard" : "Haz clic para copiar el enlace al portapapeles",
    "Toggle sharing" : "Marcar/desmarcar compartir",
    "Delete" : "Eliminar",
    "Rename" : "Cambiar nombre",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "can edit" : "puede editar",
    "Close" : "Cerrar",
    "Enabled" : "Activado",
    "Disabled" : "Desactivado",
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
    "Address book name" : "Nombre de libreta de direcciones",
    "Only these special characters are allowed: -_.!?#|()" : "Solo se admiten estos caracteres especiales: -_.!?#|()",
    "Address book could not be created." : "No se ha podido crear la libreta de direcciones.",
    "The selected image is too big (max 1MB)" : "La imagen seleccionada es demasiada grande (máximo 1MB)",
    "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Esta tarjeta esta corrupta y ha sido corregida. Por favor revise la información y ejecute guardar para hacer los cambios permanentes. ",
    "No contacts in here" : "No hay contactos aquí",
    "Name" : "Nombre",
    "Organization" : "Organización",
    "Title" : "Título",
    "Add field …" : "Añadir campo...",
    "Save changes" : "Guardar cambios",
    "Address book" : "Libro de direcciones",
    "Loading contacts …" : "Cargando contactos...",
    "Import into" : "Importar a",
    "Importing..." : "Importando...",
    "Select your addressbook" : "Selecciona tu libreta de direcciones",
    "Import is disabled because no writable address book had been found." : "La importación está desactivada porque no se ha encontrado ninguna libreta de direcciones en la que se pueda escribir.",
    "No search result for {query}" : "Sin resultados para {query}",
    "All contacts" : "Todos los contactos",
    "Post office box" : "Apartado de correos",
    "Postal code" : "Código postal",
    "City" : "Ciudad",
    "State or province" : "Estado o provincia",
    "Country" : "País",
    "Address" : "Dirección",
    "(new group)" : "(nuevo grupo)",
    "Last name" : "Apellido",
    "First name" : "Nombre",
    "Additional names" : "Nombres adicionales",
    "Prefix" : "Prefijo",
    "Suffix" : "Sufijo",
    "Importing into" : "Importando a",
    "New contact" : "Nuevo contacto",
    "Not grouped" : "No agrupado",
    "Sort by" : "Filtrado por",
    "There is no address book available to create a contact." : "No hay libretas de direcciones disponibles para crear un contacto.",
    "{addressbook} shared by {owner}" : "{addressbook} compartido por {owner}",
    "Contact not found." : "Contacto no encontrado.",
    "You don't have permission to write to this addressbook." : "No tienes permiso para escribir en esta libreta de direcciones.",
    "Contact could not be created." : "No se puede crear el contacto.",
    "No contacts in file. Only vCard files are allowed." : "No hay contactos en el archivo. Solo se admiten archivos vCard.",
    "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Solo se admite las versiones de vCard 4.0 (RFC6350) o 3.0 (RFC2426).",
    "Contact could not be moved." : "No se ha podido mover el contacto.",
    "Contact could not be saved." : "No se ha podido guardar el contacto.",
    "Waiting for the server to be ready…" : "Esperando a que el servidor esté preparado...",
    "Importing…" : "Importando...",
    "Display name" : "Nombre mostrado",
    "Nickname" : "Apodo",
    "Detailed name" : "Nombre",
    "Notes" : "Notas",
    "Website" : "Sitio web",
    "Federated Cloud ID" : "ID Nube Federada",
    "Home" : "Casa",
    "Work" : "Trabajo",
    "Other" : "Otro",
    "Groups" : "Grupos",
    "Birthday" : "Fecha de nacimiento",
    "Anniversary" : "Aniversario",
    "Date of death" : "Fecha de fallecimiento",
    "Email" : "Correo electrónico",
    "Instant messaging" : "Mensajería instantánea",
    "Phone" : "Teléfono",
    "Mobile" : "Móvil",
    "Work mobile" : "Móvil del trabajo",
    "Fax" : "Fax",
    "Fax home" : "Fax hogareño",
    "Fax work" : "Fax del trabajo",
    "Pager" : "Localizador",
    "Voice" : "Voz",
    "Car" : "Coche",
    "Work pager" : "Busca del trabajo",
    "Social network" : "Redes sociales",
    "Relationship" : "Relación",
    "Spouse" : "Cónyuge",
    "Child" : "Hijo",
    "Mother" : "Madre",
    "Father" : "Padre",
    "Parent" : "Progenitor",
    "Brother" : "Hermano",
    "Sister" : "Hermana",
    "Relative" : "Pariente",
    "Friend" : "Amigo",
    "Colleague" : "Colega",
    "Manager" : "Mánager",
    "Assistant" : "Asistente",
    "Gender" : "Género",
    "Female" : "Mujer",
    "Male" : "Hombre",
    "Details" : "Detalles",
    "Settings" : "Ajustes"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-contacts-2.1.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/es.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contactos",
    "Download" : "Descargar",
    "Copy link" : "Copiar enlace",
    "Click to copy the link to your clipboard" : "Haz clic para copiar el enlace al portapapeles",
    "Toggle sharing" : "Marcar/desmarcar compartir",
    "Delete" : "Eliminar",
    "Rename" : "Cambiar nombre",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "can edit" : "puede editar",
    "Close" : "Cerrar",
    "Enabled" : "Activado",
    "Disabled" : "Desactivado",
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
    "Address book name" : "Nombre de libreta de direcciones",
    "Only these special characters are allowed: -_.!?#|()" : "Solo se admiten estos caracteres especiales: -_.!?#|()",
    "Address book could not be created." : "No se ha podido crear la libreta de direcciones.",
    "Upload new image" : "Subir nueva imagen",
    "The selected image is too big (max 1MB)" : "La imagen seleccionada es demasiada grande (máximo 1MB)",
    "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Esta tarjeta esta corrupta y ha sido corregida. Por favor revise la información y ejecute guardar para hacer los cambios permanentes. ",
    "No contacts in here" : "No hay contactos aquí",
    "Name" : "Nombre",
    "Organization" : "Organización",
    "Title" : "Título",
    "Add field …" : "Añadir campo...",
    "Save changes" : "Guardar cambios",
    "Address book" : "Libro de direcciones",
    "Loading contacts …" : "Cargando contactos...",
    "Import into" : "Importar a",
    "Importing..." : "Importando...",
    "Select your addressbook" : "Selecciona tu libreta de direcciones",
    "Import is disabled because no writable address book had been found." : "La importación está desactivada porque no se ha encontrado ninguna libreta de direcciones en la que se pueda escribir.",
    "No search result for {query}" : "Sin resultados para {query}",
    "All contacts" : "Todos los contactos",
    "Post office box" : "Apartado de correos",
    "Postal code" : "Código postal",
    "City" : "Ciudad",
    "State or province" : "Estado o provincia",
    "Country" : "País",
    "Address" : "Dirección",
    "(new group)" : "(nuevo grupo)",
    "Last name" : "Apellido",
    "First name" : "Nombre",
    "Additional names" : "Nombres adicionales",
    "Prefix" : "Prefijo",
    "Suffix" : "Sufijo",
    "Importing into" : "Importando a",
    "New contact" : "Nuevo contacto",
    "Not grouped" : "No agrupado",
    "Sort by" : "Filtrado por",
    "There is no address book available to create a contact." : "No hay libretas de direcciones disponibles para crear un contacto.",
    "{addressbook} shared by {owner}" : "{addressbook} compartido por {owner}",
    "Contact not found." : "Contacto no encontrado.",
    "You don't have permission to write to this addressbook." : "No tienes permiso para escribir en esta libreta de direcciones.",
    "Contact could not be created." : "No se puede crear el contacto.",
    "No contacts in file. Only vCard files are allowed." : "No hay contactos en el archivo. Solo se admiten archivos vCard.",
    "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Solo se admite las versiones de vCard 4.0 (RFC6350) o 3.0 (RFC2426).",
    "Contact could not be moved." : "No se ha podido mover el contacto.",
    "Contact could not be saved." : "No se ha podido guardar el contacto.",
    "Waiting for the server to be ready…" : "Esperando a que el servidor esté preparado...",
    "Importing…" : "Importando...",
    "Display name" : "Nombre mostrado",
    "Nickname" : "Apodo",
    "Detailed name" : "Nombre",
    "Notes" : "Notas",
    "Website" : "Sitio web",
    "Federated Cloud ID" : "ID Nube Federada",
    "Home" : "Casa",
    "Work" : "Trabajo",
    "Other" : "Otro",
    "Groups" : "Grupos",
    "Birthday" : "Fecha de nacimiento",
    "Anniversary" : "Aniversario",
    "Date of death" : "Fecha de fallecimiento",
    "Email" : "Correo electrónico",
    "Instant messaging" : "Mensajería instantánea",
    "Phone" : "Teléfono",
    "Mobile" : "Móvil",
    "Work mobile" : "Móvil del trabajo",
    "Fax" : "Fax",
    "Fax home" : "Fax hogareño",
    "Fax work" : "Fax del trabajo",
    "Pager" : "Localizador",
    "Voice" : "Voz",
    "Car" : "Coche",
    "Work pager" : "Busca del trabajo",
    "Social network" : "Redes sociales",
    "Relationship" : "Relación",
    "Specify a relationship between you and the entity represented by this vCard." : "Especifica una relación entre tú y la entidad representada por esta vCard.",
    "Spouse" : "Cónyuge",
    "Child" : "Hijo",
    "Mother" : "Madre",
    "Father" : "Padre",
    "Parent" : "Progenitor",
    "Brother" : "Hermano",
    "Sister" : "Hermana",
    "Relative" : "Pariente",
    "Friend" : "Amigo",
    "Colleague" : "Colega",
    "Manager" : "Mánager",
    "Assistant" : "Asistente",
    "Related" : "Relacionado",
    "Specify a relationship between another entity and the entity represented by this vCard." : "Especifica una relación entre otra entidad y la entidad representada por esta vCard.",
    "Contact" : "Contacto",
    "Agent" : "Agente",
    "Emergency" : "Emergencia",
    "Co-worker" : "Compañero de trabajo",
    "Gender" : "Género",
    "Female" : "Mujer",
    "Male" : "Hombre",
    "Details" : "Detalles",
    "A contacts app for Nextcloud" : "Una app de contactos para Nextcloud.",
    "Settings" : "Ajustes"
},
"nplurals=2; plural=(n != 1);");
